import { http, httpGet } from '@/utils/http'

export interface IFooItem {
  id: string
  name: string
}

export interface UserT {
  token: string
  nickname: string
  login_telegram: string
  register_status: number
}

export interface LoginI {
  coin_address?: string
  scene?: string
  terminal?: string
  share_code?: string
  firstName: string
  id: string | number
  languageCode: string
  lastName: string
  username: string
  token?: string
}

export interface UserCenter {
  id: number
  sn: number
  account: string
  nickname: string
  real_name: string
  avatar: string
  create_time: string
  gold_coin: number
  key: number
  development_gold_coin: number
  history_gold_coin: number
  history_key: number
  usdt: number
  total_development_gold: number
  stamina: number
  total_share_reward: number
  total_task_reward: number
  total_team_reward: number
  total_development_reward: number
  total_resource_reward: number
}
interface LoginCheck {
  show: number
}
export interface JinbiT {
  id: number
  sn: number
  account: string
  nickname: string
  real_name: string
  avatar: string
  create_time: string
  gold_coin: number
  key: number
  development_gold_coin: number
  history_gold_coin: number
  history_key: number
  usdt: number | null
  stamina: number
  temporary_status: number
  temporary_start_time: number
  temporary_coin: number
  temporary_time: number
  total_development_gold: number
}

export interface ProductionIncreaseInterface {
  id: number
  name: string
  level: number
  gold_coin: number
  value: number
  image: string
  upgrades: boolean
}
/** GET 请求 */
export const getFooAPI = (name: string) => {
  return http.get<IFooItem>('/foo', { name })
}

/** POST 请求 */
export const postFooAPI = (name: string) => {
  return http.post<IFooItem>('/foo', { name }, { name })
}
// 登录接口
export const coinLoginApi = (data: LoginI) => {
  return httpGet<UserT>('/api/login/coinLogin', data)
}

// 获取当前登录用户金币数量
export const getUserCoinApi = () => {
  return httpGet<UserCenter>('/api/development/center')
}

// 统计用户在线时长
export const updateOnlineTime = (onlineTime: number) => {
  return http.post<UserCenter>('/api/user/updateOnlineTime', { online_time: onlineTime })
}
// 设置金币
export const updateClikckAddCoin = (goldCoin: number) => {
  return http.post<any>('/api/user/clikckAddCoin', { gold_coin: goldCoin })
}
// 设置体力
export const updateStamina = (stamina: number) => {
  return http.post<any>('/api/user/updateStamina', { stamina })
}

// 检查是否注册过
export const coinLoginCheck = (id: number) => {
  return http.get<LoginCheck>('/api/login/coinLoginCheck', { terminal: 3, id })
}

// 开始金币活动
export const startCoinGame = (startTime: string) => {
  return http.post<LoginCheck>('/api/user/startCoinGame', { start_time: startTime })
}

// 获取当前金币数量改版
export const getDevelopmentCenter = () => {
  return http.get<JinbiT>('/api/development/center')
}
// 设置金币
export const stageCoinAdd = () => {
  return http.post<any>('/api/user/stageCoinAdd')
}

// 获取推进器信息
export const propellerAllTwo = () => {
  return http.get<ProductionIncreaseInterface[]>('/api/propeller/propellerAllTwo')
}
// 升级推进器
export const prepellerDeduction = (id: number) => {
  return http.post<any>('/api/propeller/prepellerDeduction', { id })
}

// 存入当前语言 user/checkLanguage
export const postCheckLang = (lang: string) => {
  return http.post<any>('/api/user/checkLanguage', { lang })
}
